=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2013-11-07 13:54:18 +0000
+++ CMakeLists.txt	2013-12-28 17:34:36 +0000
@@ -258,6 +258,7 @@
 add_subdirectory(launcher)
 if (ENABLE_X_SUPPORT)
   add_subdirectory(hud)
+  add_subdirectory(lockscreen)
   add_subdirectory(panel)
   add_subdirectory(plugins/unityshell)
   add_subdirectory(plugins/networkarearegion)

=== modified file 'UnityCore/SessionManager.h'
--- UnityCore/SessionManager.h	2013-02-21 18:14:47 +0000
+++ UnityCore/SessionManager.h	2013-12-28 17:34:36 +0000
@@ -57,6 +57,8 @@
   Manager& operator=(const Manager&) = delete;
 
   sigc::signal<void, bool /* inhibitors */> logout_requested;
+  sigc::signal<void> lock_requested;
+  sigc::signal<void> unlock_requested;
   sigc::signal<void, bool /* inhibitors */> reboot_requested;
   sigc::signal<void, bool /* inhibitors */> shutdown_requested;
 

=== added directory 'lockscreen'
=== added file 'lockscreen/CMakeLists.txt'
--- lockscreen/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ lockscreen/CMakeLists.txt	2013-12-28 17:34:36 +0000
@@ -0,0 +1,33 @@
+set(UNITY_SRC ../plugins/unityshell/src)
+
+set (CFLAGS
+     ${CACHED_UNITY_DEPS_CFLAGS}
+     ${CACHED_UNITY_DEPS_CFLAGS_OTHER}
+     ${PIC_FLAGS}
+     )
+
+string (REPLACE ";" " " CFLAGS "${CFLAGS}")
+set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} ${CFLAGS}")
+
+set (LIBS ${CACHED_UNITY_DEPS_LDFLAGS} ${UNITY_STANDALONE_LADD})
+
+include_directories (.. ../services ../UnityCore ${UNITY_SRC} ${CMAKE_BINARY_DIR})
+
+#
+# Headers & Sources
+#
+set (LOCKSCREEN_SOURCES
+     LockScreenController.cpp
+     LockScreenShield.cpp
+     UserAuthenticatorPam.cpp
+     )
+
+add_library (lockscreen-lib STATIC ${LOCKSCREEN_SOURCES})
+add_dependencies (lockscreen-lib unity-core-${UNITY_API_VERSION} unity-shared)
+add_pch(pch/lockscreen_pch.hh lockscreen-lib)
+
+#
+# Standalone variant
+#
+add_executable (lockscreen StandaloneLockScreen.cpp)
+target_link_libraries (lockscreen lockscreen-lib unity-shared unity-shared-standalone)

=== added file 'lockscreen/LockScreenController.cpp'
--- lockscreen/LockScreenController.cpp	1970-01-01 00:00:00 +0000
+++ lockscreen/LockScreenController.cpp	2013-12-28 17:34:36 +0000
@@ -0,0 +1,109 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+* Copyright (C) 2013 Canonical Ltd
+*
+* This program is free software: you can redistribute it and/or modify
+* it under the terms of the GNU General Public License version 3 as
+* published by the Free Software Foundation.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*
+* Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
+*/
+
+#include "LockScreenController.h"
+#include "unity-shared/UScreen.h"
+
+namespace unity
+{
+namespace lockscreen
+{
+
+Controller::Controller(session::Manager::Ptr const& manager)
+  : manager_(manager)
+  , locked_(false) // FIXME unity can start in lock state!
+{
+  auto* uscreen = UScreen::GetDefault();
+  EnsureShields(uscreen->GetMonitorWithMouse(), uscreen->GetMonitors());
+
+  uscreen->changed.connect(sigc::mem_fun(this, &Controller::OnUScreenChanged));
+  manager_->lock_requested.connect(sigc::mem_fun(this, &Controller::OnLockRequested));
+  manager_->unlock_requested.connect(sigc::mem_fun(this, &Controller::OnUnlockRequested));
+}
+
+void Controller::OnUScreenChanged(int primary, std::vector<nux::Geometry> const& monitors)
+{
+  auto* uscreen = UScreen::GetDefault();
+  EnsureShields(uscreen->GetMonitorWithMouse(), monitors);
+}
+
+void Controller::EnsureShields(int monitor_with_mouse, std::vector<nux::Geometry> const& monitors)
+{
+  int num_monitors = monitors.size();
+  int num_shields = num_monitors;
+  int shields_size = shields_.size();
+  int last_shield = 0;
+
+  for (int i = 0; i < num_shields; ++i, ++last_shield)
+  {
+    if (i >= shields_size)
+    {
+      shields_.push_back(CreateShield(i == monitor_with_mouse));
+    }
+    else if (!shields_.at(i))
+    {
+      shields_[i] = CreateShield(i == monitor_with_mouse);
+    }
+
+    shields_[i]->SetGeometry(monitors.at(i));
+  }
+
+  for (int i = last_shield; i < shields_size; ++i)
+  {
+  }
+
+  shields_.resize(num_shields);
+}
+
+nux::ObjectPtr<Shield> Controller::CreateShield(bool is_monitor_with_mouse)
+{
+  nux::ObjectPtr<Shield> shield(new Shield(is_monitor_with_mouse));
+  return shield;
+}
+
+void Controller::OnLockRequested()
+{
+  if (locked_)
+    return;
+
+  std::for_each(shields_.begin(), shields_.end(), [](nux::ObjectPtr<Shield> const& shield) {
+    shield->SetOpacity(1.0f);
+    shield->ShowWindow(true);
+  });
+
+  locked_ = true;
+}
+
+void Controller::OnUnlockRequested()
+{
+  if (!locked_)
+    return;
+
+  std::for_each(shields_.begin(), shields_.end(), [](nux::ObjectPtr<Shield> const& shield) {
+    shield->SetOpacity(0.0f);
+    shield->ShowWindow(false);
+  });
+
+  locked_ = false;
+}
+
+
+
+}
+}
\ No newline at end of file

=== added file 'lockscreen/LockScreenController.h'
--- lockscreen/LockScreenController.h	1970-01-01 00:00:00 +0000
+++ lockscreen/LockScreenController.h	2013-12-28 17:34:36 +0000
@@ -0,0 +1,55 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+* Copyright (C) 2013 Canonical Ltd
+*
+* This program is free software: you can redistribute it and/or modify
+* it under the terms of the GNU General Public License version 3 as
+* published by the Free Software Foundation.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*
+* Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
+*/
+
+#ifndef UNITY_LOCKSCREEN_CONTROLLER_H
+#define UNITY_LOCKSCREEN_CONTROLLER_H
+
+#include <memory>
+#include <sigc++/trackable.h>
+
+#include "LockScreenShield.h"
+#include <UnityCore/SessionManager.h>
+
+namespace unity
+{
+namespace lockscreen
+{
+
+class Controller : public sigc::trackable
+{
+public:
+  Controller(session::Manager::Ptr const& manager);
+
+private:
+  void EnsureShields(int monitor_with_mouse, std::vector<nux::Geometry> const& monitors);
+  nux::ObjectPtr<Shield> CreateShield(bool is_monitor_with_mouse);
+
+  void OnUScreenChanged(int primary, std::vector<nux::Geometry> const& monitors);
+  void OnLockRequested();
+  void OnUnlockRequested();
+
+  session::Manager::Ptr const& manager_;
+  std::vector<nux::ObjectPtr<Shield>> shields_;
+  bool locked_;
+};
+
+}
+}
+
+#endif
\ No newline at end of file

=== added file 'lockscreen/LockScreenShield.cpp'
--- lockscreen/LockScreenShield.cpp	1970-01-01 00:00:00 +0000
+++ lockscreen/LockScreenShield.cpp	2013-12-28 17:34:36 +0000
@@ -0,0 +1,56 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+* Copyright (C) 2013 Canonical Ltd
+*
+* This program is free software: you can redistribute it and/or modify
+* it under the terms of the GNU General Public License version 3 as
+* published by the Free Software Foundation.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*
+* Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
+*/
+
+#include "LockScreenShield.h"
+
+#include <NuxCore/Color.h> // FIXME: remove this
+
+namespace unity 
+{
+namespace lockscreen
+{
+
+Shield::Shield(bool is_primary)
+  : primary(is_primary)
+{
+  SetBackgroundColor(is_primary ?  nux::color::Red : nux::color::Yellow);
+
+  mouse_enter.connect(sigc::mem_fun(this, &Shield::OnMouseEnter));
+  mouse_leave.connect(sigc::mem_fun(this, &Shield::OnMouseLeave));
+  primary.changed.connect(sigc::mem_fun(this, &Shield::OnPrimaryChanged));
+}
+
+void Shield::OnMouseEnter(int /*x*/, int /*y*/, unsigned long /**/, unsigned long /**/)
+{
+  primary = true;
+}
+
+void Shield::OnMouseLeave(int /*x*/, int /**/, unsigned long /**/, unsigned long /**/)
+{
+  primary = false;
+}
+
+void Shield::OnPrimaryChanged(bool value)
+{
+  SetBackgroundColor(value ?  nux::color::Red : nux::color::Yellow);
+  QueueDraw();
+}
+
+}
+}

=== added file 'lockscreen/LockScreenShield.h'
--- lockscreen/LockScreenShield.h	1970-01-01 00:00:00 +0000
+++ lockscreen/LockScreenShield.h	2013-12-28 17:34:36 +0000
@@ -0,0 +1,47 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+* Copyright (C) 2013 Canonical Ltd
+*
+* This program is free software: you can redistribute it and/or modify
+* it under the terms of the GNU General Public License version 3 as
+* published by the Free Software Foundation.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*
+* Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
+*/
+
+#ifndef UNITY_LOCKSCREEN_SHIELD_H
+#define UNITY_LOCKSCREEN_SHIELD_H
+
+#include <Nux/BaseWindow.h>
+#include <NuxCore/Property.h>
+
+namespace unity
+{
+namespace lockscreen
+{
+
+class Shield : public nux::BaseWindow
+{
+public:
+  Shield(bool is_primary);
+
+  nux::Property<bool> primary;
+
+private:
+  void OnMouseEnter(int /*x*/, int /*y*/, unsigned long /**/, unsigned long /**/);
+  void OnMouseLeave(int /*x*/, int /**/, unsigned long /**/, unsigned long /**/);
+  void OnPrimaryChanged(bool value);
+};
+
+}
+}
+
+#endif
\ No newline at end of file

=== added file 'lockscreen/StandaloneLockScreen.cpp'
--- lockscreen/StandaloneLockScreen.cpp	1970-01-01 00:00:00 +0000
+++ lockscreen/StandaloneLockScreen.cpp	2013-12-28 17:34:36 +0000
@@ -0,0 +1,93 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+ * Copyright (C) 2013 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
+ */
+
+//#include "config.h"
+//#include <glib/gi18n-lib.h>
+#include <gtk/gtk.h>
+#include <Nux/Nux.h>
+//#include <Nux/NuxTimerTickSource.h>
+#include <Nux/WindowThread.h>
+//#include <NuxCore/AnimationController.h>
+
+#include "LockScreenController.h"
+//#include "unity-shared/UnitySettings.h"
+
+class MockSessionManager : public unity::session::Manager
+{
+public:
+  std::string RealName() const { return ""; }
+  std::string UserName() const { return ""; }
+
+  void LockScreen() {}
+  void Logout() {}
+  void Reboot() {}
+  void Shutdown() {}
+  void Suspend() {}
+  void Hibernate() {}
+
+  void CancelAction() {}
+
+  bool CanShutdown() const {return true;}
+  bool CanSuspend() const {return true;}
+  bool CanHibernate() const {return true;}
+};
+
+struct LockScreenWindow
+{
+  LockScreenWindow()
+    : wt(nux::CreateGUIThread("Unity LockScreen Controller", 1024, 300, 0, &LockScreenWindow::ThreadWidgetInit, this))
+    //, animation_controller(tick_source)
+  {}
+
+  void Show()
+  {
+    wt->Run(nullptr);
+  }
+
+private:
+  void Init();
+
+  static void ThreadWidgetInit(nux::NThread* thread, void* self)
+  {
+    static_cast<LockScreenWindow*>(self)->Init();
+  }
+
+  //unity::Settings settings;
+  std::shared_ptr<nux::WindowThread> wt;
+  //nux::NuxTimerTickSource tick_source;
+  //nux::animation::AnimationController animation_controller;
+  std::shared_ptr<unity::lockscreen::Controller> controller;
+};
+
+void LockScreenWindow::Init()
+{
+  auto manager = std::make_shared<MockSessionManager>();
+  controller = std::make_shared<unity::lockscreen::Controller>(manager);
+  manager->lock_requested.emit();
+}
+
+int main(int argc, char** argv)
+{
+  gtk_init(&argc, &argv);
+
+  nux::NuxInitialize(0);
+  LockScreenWindow().Show();
+
+  return 0;
+}

=== added file 'lockscreen/UserAuthenticator.h'
--- lockscreen/UserAuthenticator.h	1970-01-01 00:00:00 +0000
+++ lockscreen/UserAuthenticator.h	2013-12-28 17:34:36 +0000
@@ -0,0 +1,48 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+ * Copyright (C) 2013 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
+ */
+
+ #ifndef UNITY_USER_AUTHENTICATOR_H
+ #define UNITY_USER_AUTHENTICATOR_H
+
+#include <functional>
+#include <string>
+ 
+namespace unity
+{
+namespace lockscreen
+{
+
+class UserAuthenticator
+{
+public:
+  typedef std::function<void(bool)> AuthenticateEndCallback;
+
+  virtual ~UserAuthenticator() {}
+
+  // Authenticate the user in a background thread.
+  virtual bool AuthenticateStart(std::string const& username,
+                                 std::string const& password,
+                                 AuthenticateEndCallback authenticate_cb) = 0;
+};
+
+} // lockscreen
+} // unity
+ 
+ 
+ #endif // UNITY_USER_AUTHENTICATOR_H

=== added file 'lockscreen/UserAuthenticatorPam.cpp'
--- lockscreen/UserAuthenticatorPam.cpp	1970-01-01 00:00:00 +0000
+++ lockscreen/UserAuthenticatorPam.cpp	2013-12-28 17:34:36 +0000
@@ -0,0 +1,130 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+ * Copyright (C) 2013 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
+ */
+
+// Kindly inspired by user_authenticator_linux.cc of chromium project
+// TODO (andy) Would be nice to make it more thread-safe and to imporve 
+// the API and the cody style
+#include "UserAuthenticatorPam.h"
+
+#include <security/pam_appl.h>
+#include <UnityCore/GLibWrapper.h>
+
+namespace unity
+{
+namespace lockscreen
+{
+
+bool UserAuthenticatorPam::AuthenticateStart(std::string const& username,
+                                             std::string const& password,
+                                             AuthenticateEndCallback authenticate_cb)
+{
+  username_ = username;
+  password_ = password;
+  authenticate_cb_ = authenticate_cb;
+
+  // FIXME: would be nice to support a fallback in case PAM
+  // is not available.
+  if (!InitPam())
+    return false;
+
+  glib::Object<GTask> task(g_task_new(nullptr, nullptr, [] (GObject*, GAsyncResult*, gpointer data) {
+    auto self = static_cast<UserAuthenticatorPam*>(data);
+    pam_end(self->pam_handle_, self->status_);
+    self->authenticate_cb_(self->status_ == PAM_SUCCESS);
+  }, this));
+
+  g_task_set_task_data(task, this, nullptr);
+
+  g_task_run_in_thread(task, [] (GTask* task, gpointer, gpointer data, GCancellable*) {
+    auto self = static_cast<UserAuthenticatorPam*>(data);
+    self->status_ = pam_authenticate(self->pam_handle_, 0);
+  });
+
+  return true;
+}
+
+bool UserAuthenticatorPam::InitPam()
+{
+  pam_conv conversation;
+  conversation.conv = ConverationFunction;
+  conversation.appdata_ptr = static_cast<void*>(this);
+
+  return pam_start(/*FIXME*/ "gnome_screensaver", username_.c_str(),
+                   &conversation, &pam_handle_) == PAM_SUCCESS;
+}
+
+int UserAuthenticatorPam::ConverationFunction(int num_msg,
+                                              const pam_message** msg,
+                                              pam_response** resp,
+                                              void* appdata_ptr)
+{
+  if (num_msg <= 0)
+    return PAM_CONV_ERR;
+
+  auto* tmp_response = static_cast<pam_response*>(malloc(num_msg * sizeof(pam_response)));
+  if (!tmp_response)
+    return PAM_CONV_ERR;
+
+  UserAuthenticatorPam* user_auth = static_cast<UserAuthenticatorPam*>(appdata_ptr);
+
+  bool raise_error = false;
+  int count;
+  for (count = 0; count < num_msg && !raise_error; ++count)
+  {
+    pam_response* resp_item = &tmp_response[count];
+    resp_item->resp_retcode = 0;
+    resp_item->resp = nullptr;
+
+    switch (msg[count]->msg_style)
+    {
+      case PAM_PROMPT_ECHO_ON:
+        resp_item->resp = strdup(user_auth->username_.c_str());
+        if (!resp_item->resp)
+          raise_error = true;
+        break;
+      case PAM_PROMPT_ECHO_OFF:
+        resp_item->resp = strdup(user_auth->password_.c_str());
+        if (!resp_item->resp)
+          raise_error = true;
+        break;
+      case PAM_TEXT_INFO:
+        break;
+      default:
+        raise_error = true;
+    }
+  }
+
+  if (raise_error)
+  {
+    for (int i = 0; i < count; ++i)
+      if (tmp_response[i].resp)
+        free(tmp_response[i].resp);
+
+    free(tmp_response);
+    return PAM_CONV_ERR;
+  }
+  else
+  {
+    *resp = tmp_response;
+    return PAM_SUCCESS;
+  }
+}
+
+}  // lockscreen
+} // unity

=== added file 'lockscreen/UserAuthenticatorPam.h'
--- lockscreen/UserAuthenticatorPam.h	1970-01-01 00:00:00 +0000
+++ lockscreen/UserAuthenticatorPam.h	2013-12-28 17:34:36 +0000
@@ -0,0 +1,64 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+ * Copyright (C) 2013 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
+ */
+
+#ifndef UNITY_USER_AUTHENTICATOR_PAM_H
+#define UNITY_USER_AUTHENTICATOR_PAM_H
+
+#include <boost/noncopyable.hpp>
+
+#include "UserAuthenticator.h"
+
+// Forware declarations
+struct pam_handle;
+struct pam_message;
+struct pam_response;
+
+namespace unity
+{
+namespace lockscreen
+{
+
+class UserAuthenticatorPam : public UserAuthenticator, private boost::noncopyable
+{
+public:
+  bool AuthenticateStart(std::string const& username,
+                         std::string const& password,
+                         AuthenticateEndCallback authenticate_cb) override;
+
+private:
+  // TODO: move to pimpl
+  bool InitPam();
+
+  static int ConverationFunction(int num_msg,
+                                 const pam_message** msg,
+                                 pam_response** resp,
+                                 void* appdata_ptr);
+
+  std::string username_;
+  std::string password_;
+  AuthenticateEndCallback authenticate_cb_;
+
+  int status_;
+  pam_handle* pam_handle_;
+};
+
+} // lockscreen
+} // unity
+
+#endif // UNITY_USER_AUTHENTICATOR_PAM_H
\ No newline at end of file

=== added directory 'lockscreen/pch'
=== added file 'lockscreen/pch/lockscreen_pch.hh'
--- lockscreen/pch/lockscreen_pch.hh	1970-01-01 00:00:00 +0000
+++ lockscreen/pch/lockscreen_pch.hh	2013-12-28 17:34:36 +0000
@@ -0,0 +1,27 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+ * Copyright (C) 2013 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
+ */
+
+/*
+ * These are the precompiled header includes for this module.
+ * Only system header files can be listed here.
+ */
+
+#include <memory>
+ 
+#include <Nux/BaseWindow.h>
\ No newline at end of file

=== modified file 'tests/CMakeLists.txt'
--- tests/CMakeLists.txt	2013-11-14 00:17:19 +0000
+++ tests/CMakeLists.txt	2013-12-28 17:34:36 +0000
@@ -313,6 +313,7 @@
                  test_unity_settings.cpp
                  test_unity_window_style.cpp
                  test_unity_window_view.cpp
+                 test_user_authenticator_pam.cpp
                  test_volume_launcher_icon.cpp
                  test_window_buttons.cpp
                  test_xdnd_manager_imp.cpp
@@ -337,6 +338,7 @@
                         unity-shared
                         ${LIBS}
                         launcher-lib
+                        lockscreen-lib
                         unity-shared-bamf
                         unity-shared-standalone
                         shortcuts-lib
@@ -345,7 +347,8 @@
                         switcher-lib
                         shutdown-lib
                         dash-lib
-                        panel-lib)
+                        panel-lib
+                        pam)
   add_test(UnityGTest test-gtest)
 endif (ENABLE_X_SUPPORT)
 endif (GMOCK_LIB AND

=== added file 'tests/test_user_authenticator_pam.cpp'
--- tests/test_user_authenticator_pam.cpp	1970-01-01 00:00:00 +0000
+++ tests/test_user_authenticator_pam.cpp	2013-12-28 17:34:36 +0000
@@ -0,0 +1,78 @@
+// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
+/*
+ * Copyright (C) 2013 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
+ */
+
+#include <gtest/gtest.h>
+
+#include "lockscreen/UserAuthenticatorPam.h"
+#include "test_utils.h"
+
+using unity::lockscreen::UserAuthenticatorPam;
+
+#include <security/pam_appl.h>
+
+// Would be nice to build a testing pam module, but writing a
+// pam_authenticate function here works just fine for the moment.
+int pam_authenticate(pam_handle_t *pamh, int flags)
+{
+  pam_conv* conversation;
+  struct pam_message msg;
+  const struct pam_message *msgp;
+
+  pam_get_item(pamh, PAM_CONV, (const void**) &conversation);
+
+  msg.msg_style = PAM_PROMPT_ECHO_OFF;
+  msgp = &msg;
+
+  pam_response* resp = nullptr;
+  conversation->conv(1, &msgp, &resp, conversation->appdata_ptr);
+
+  return strcmp(resp[0].resp, "password");
+}
+
+namespace
+{
+
+struct TestUserAuthenticatorPam : public ::testing::Test
+{
+  UserAuthenticatorPam user_authenticator_pam_;
+};
+
+TEST_F(TestUserAuthenticatorPam, AuthenticateStart)
+{
+  bool authentication_result = false;
+
+  user_authenticator_pam_.AuthenticateStart("andrea", "password", [&authentication_result](bool success) {
+    authentication_result = success;
+  });
+
+  Utils::WaitUntilMSec(authentication_result);
+}
+
+TEST_F(TestUserAuthenticatorPam, AuthenticateStartWrongPassword)
+{
+  bool authentication_result = false;
+
+  user_authenticator_pam_.AuthenticateStart("maria", "wrong password", [&authentication_result](bool success) {
+    authentication_result = not success;
+  });
+
+  Utils::WaitUntilMSec(authentication_result);
+}
+
+}

=== modified file 'unity-shared/UScreen.cpp'
--- unity-shared/UScreen.cpp	2013-11-14 03:00:29 +0000
+++ unity-shared/UScreen.cpp	2013-12-28 17:34:36 +0000
@@ -86,6 +86,9 @@
 
 std::vector<nux::Geometry>& UScreen::GetMonitors()
 {
+  monitors_.clear();
+  monitors_.push_back(nux::Geometry(0,0,500,500));
+  monitors_.push_back(nux::Geometry(500,200,500,500));
   return monitors_;
 }
 

